@@ -1,5 +1,5 @@
 __name__ = "optcom"
-__version__ = "0.2.0"
+__version__ = "0.3.1"
 # need Docstring doc
 
 # from components
@@ -89,7 +89,9 @@ from optcom.parameters.fiber.doped_fiber_gain import DopedFiberGain
 from optcom.parameters.fiber.effective_area import EffectiveArea
 from optcom.parameters.fiber.emission_section import EmissionSection
 from optcom.parameters.fiber.energy_saturation import EnergySaturation
+from optcom.parameters.fiber.fiber_recovery_time import FiberRecoveryTime
 from optcom.parameters.fiber.nl_coefficient import NLCoefficient
+from optcom.parameters.fiber.nl_phase_shift import NLPhaseShift
 from optcom.parameters.fiber.numerical_aperture import NumericalAperture
 from optcom.parameters.fiber.overlap_factor import OverlapFactor
 from optcom.parameters.fiber.raman_response import RamanResponse
@@ -102,9 +104,10 @@ from optcom.parameters.refractive_index.sellmeier import Sellmeier
 
 mod_para = ['AbsorptionSection', 'ChromaticDisp', 'AsymmetryCoeff',
             'CouplingCoeff', 'DopedFiberGain', 'EffectiveArea',
-            'EmissionSection', 'EnergySaturation', 'NLCoefficient',
-            'NumericalAperture', 'OverlapFactor', 'RamanResponse',
-            'SEPower', 'VNumber', 'NLIndex', 'ResonantIndex', 'Sellmeier']
+            'EmissionSection', 'EnergySaturation', 'FiberRecoveryTime',
+            'NLCoefficient', 'NLPhaseShift', 'NumericalAperture',
+            'OverlapFactor', 'RamanResponse', 'SEPower', 'VNumber', 'NLIndex',
+            'ResonantIndex', 'Sellmeier']
 
 
 
