@@ -99,12 +99,12 @@ class GaussianFilter(AbstractPassComp):
             specified maximum number of pass for this port.
         pre_call_code :
             A string containing code which will be executed prior to
-            the call to the function :func:`__call__`. The two parameters
-            `input_ports` and `input_fields` are available.
+            the call to the function :func:`__call__`. The two
+            parameters `input_ports` and `input_fields` are available.
         post_call_code :
             A string containing code which will be executed posterior to
-            the call to the function :func:`__call__`. The two parameters
-            `output_ports` and `output_fields` are available.
+            the call to the function :func:`__call__`. The two
+            parameters `output_ports` and `output_fields` are available.
 
         """
         # Parent constructor -------------------------------------------
@@ -175,4 +175,4 @@ if __name__ == "__main__":
     y_labels: List[str] = ['P_t', 'P_t', 'P_nu', 'P_nu']
 
     oc.plot2d(x_datas, y_datas, plot_titles=plot_titles, x_labels=x_labels,
-              y_labels=y_labels, split=True, opacity=[0.3])
+              y_labels=y_labels, split=True, line_opacities=[0.3])
