@@ -133,12 +133,12 @@ class IdealMZM(AbstractPassComp):
             specified maximum number of pass for this port.
         pre_call_code :
             A string containing code which will be executed prior to
-            the call to the function :func:`__call__`. The two parameters
-            `input_ports` and `input_fields` are available.
+            the call to the function :func:`__call__`. The two
+            parameters `input_ports` and `input_fields` are available.
         post_call_code :
             A string containing code which will be executed posterior to
-            the call to the function :func:`__call__`. The two parameters
-            `output_ports` and `output_fields` are available.
+            the call to the function :func:`__call__`. The two
+            parameters `output_ports` and `output_fields` are available.
 
         """
         # Parent constructor -------------------------------------------
@@ -342,4 +342,4 @@ if __name__ == "__main__":
     x_datas: List[np.ndarray] = [pulse[0][0].time, mz[1][0].time]
 
     oc.plot2d(x_datas, y_datas, split=True, plot_titles=plot_titles,
-              x_labels=['t'], y_labels=['P_t'], opacity=[0.3])
+              x_labels=['t'], y_labels=['P_t'], line_opacities=[0.3])
